==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ResourceSetBindingAddMembersRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindingAddMembersRequest
 */
@JsonPropertyOrder({ ResourceSetBindingAddMembersRequest.JSON_PROPERTY_ADDITIONS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResourceSetBindingAddMembersRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ADDITIONS = "additions";
    private List<String> additions = null;

    public ResourceSetBindingAddMembersRequest() {
    }

    public ResourceSetBindingAddMembersRequest additions(List<String> additions) {

        this.additions = additions;
        return this;
    }

    public ResourceSetBindingAddMembersRequest addadditionsItem(String additionsItem) {
        if (this.additions == null) {
            this.additions = new ArrayList<>();
        }
        this.additions.add(additionsItem);
        return this;
    }

    /**
     * Get additions
     *
     * @return additions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ADDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getAdditions() {
        return additions;
    }

    @JsonProperty(JSON_PROPERTY_ADDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAdditions(List<String> additions) {
        this.additions = additions;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindingAddMembersRequest resourceSetBindingAddMembersRequest = (ResourceSetBindingAddMembersRequest) o;
        return Objects.equals(this.additions, resourceSetBindingAddMembersRequest.additions);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(additions);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindingAddMembersRequest {\n");
        sb.append("    additions: ").append(toIndentedString(additions)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ResourceSetBindingAddMembersRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetBindingAddMembersRequest
 */
@JsonPropertyOrder({ ResourceSetBindingAddMembersRequest.JSON_PROPERTY_ADDITIONS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResourceSetBindingAddMembersRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ADDITIONS = "additions";
    private List<String> additions = null;

    public ResourceSetBindingAddMembersRequest() {
    }

    public ResourceSetBindingAddMembersRequest additions(List<String> additions) {

        this.additions = additions;
        return this;
    }

    public ResourceSetBindingAddMembersRequest addadditionsItem(String additionsItem) {
        if (this.additions == null) {
            this.additions = new ArrayList<>();
        }
        this.additions.add(additionsItem);
        return this;
    }

    /**
     * Get additions
     *
     * @return additions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ADDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getAdditions() {
        return additions;
    }

    @JsonProperty(JSON_PROPERTY_ADDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAdditions(List<String> additions) {
        this.additions = additions;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetBindingAddMembersRequest resourceSetBindingAddMembersRequest = (ResourceSetBindingAddMembersRequest) o;
        return Objects.equals(this.additions, resourceSetBindingAddMembersRequest.additions);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(additions);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetBindingAddMembersRequest {\n");
        sb.append("    additions: ").append(toIndentedString(additions)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
